# Rapid typing in shell, with Perika. 
[![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) 
[![Rye](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/rye/main/artwork/badge.json)](https://rye.astral.sh)

[![License - MIT](https://img.shields.io/badge/license-MIT-9400d3.svg)](https://spdx.org/licenses/) 

[![types - Mypy](https://img.shields.io/badge/types-Mypy-blue.svg)](https://github.com/python/mypy)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hatch.svg?logo=python&label=Python&logoColor=gold)](https://pypi.org/project/perika/) 


Simple console game, for training rapid typing in you favorite shell. ⌨️


## Feature
- Various text generation movements, from open APIs to LLMs
- Three levels of text complexity and number of characters.
- Pretty table score.

## Quick start


### Installation

From pypi

```shell
pip install perika-game
```

For linux\macos use Homebrew

```shell
brew install perika-game
```

